@@ -6,16 +6,16 @@ use std::path::Path;
 use std::process::Command;
 
 #[derive(Debug)]
-pub enum GcovError {
+pub enum GcovToolError {
     ProcessFailure,
     Failure((String, String, String)),
 }
 
-impl fmt::Display for GcovError {
+impl fmt::Display for GcovToolError {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match *self {
-            GcovError::ProcessFailure => write!(f, "Failed to execute gcov process"),
-            GcovError::Failure((ref path, ref stdout, ref stderr)) => {
+            GcovToolError::ProcessFailure => write!(f, "Failed to execute gcov process"),
+            GcovToolError::Failure((ref path, ref stdout, ref stderr)) => {
                 writeln!(f, "gcov execution failed on {}", path)?;
                 writeln!(f, "gcov stdout: {}", stdout)?;
                 writeln!(f, "gcov stderr: {}", stderr)
@@ -36,8 +36,8 @@ pub fn run_gcov(
     gcno_path: &Path,
     branch_enabled: bool,
     working_dir: &Path,
-) -> Result<(), GcovError> {
-    let mut command = Command::new(&get_gcov());
+) -> Result<(), GcovToolError> {
+    let mut command = Command::new(get_gcov());
     let command = if branch_enabled {
         command.arg("-b").arg("-c")
     } else {
@@ -51,11 +51,11 @@ pub fn run_gcov(
     let output = if let Ok(output) = status.output() {
         output
     } else {
-        return Err(GcovError::ProcessFailure);
+        return Err(GcovToolError::ProcessFailure);
     };
 
     if !output.status.success() {
-        return Err(GcovError::Failure((
+        return Err(GcovToolError::Failure((
             gcno_path.to_str().unwrap().to_string(),
             String::from_utf8_lossy(&output.stdout).to_string(),
             String::from_utf8_lossy(&output.stderr).to_string(),
@@ -68,7 +68,7 @@ pub fn run_gcov(
 pub fn get_gcov_version() -> &'static Version {
     lazy_static! {
         static ref V: Version = {
-            let output = Command::new(&get_gcov())
+            let output = Command::new(get_gcov())
                 .arg("--version")
                 .output()
                 .expect("Failed to execute `gcov`. `gcov` is required (it is part of GCC).");
@@ -122,5 +122,6 @@ mod tests {
             parse_version("gcov (Ubuntu 6.3.0-12ubuntu2) 6.3.0 20170406"),
             Version::new(6, 3, 0)
         );
+        assert_eq!(parse_version("gcov (GCC) 12.2.0"), Version::new(12, 2, 0));
     }
 }
