@@ -2,6 +2,7 @@
 #[global_allocator]
 static GLOBAL: tcmalloc::TCMalloc = tcmalloc::TCMalloc;
 
+use clap::{builder::PossibleValue, ArgGroup, Parser, ValueEnum};
 use crossbeam_channel::bounded;
 use log::error;
 use regex::Regex;
@@ -15,10 +16,10 @@ use std::path::{Path, PathBuf};
 use std::str::FromStr;
 use std::sync::{Arc, Mutex};
 use std::{process, thread};
-use structopt::{clap::ArgGroup, StructOpt};
 
 use grcov::*;
 
+#[derive(Clone)]
 enum OutputType {
     Ade,
     Lcov,
@@ -28,6 +29,7 @@ enum OutputType {
     Covdir,
     Html,
     Cobertura,
+    Markdown,
 }
 
 impl FromStr for OutputType {
@@ -43,11 +45,35 @@ impl FromStr for OutputType {
             "covdir" => Self::Covdir,
             "html" => Self::Html,
             "cobertura" => Self::Cobertura,
+            "markdown" => Self::Markdown,
             _ => return Err(format!("{} is not a supported output type", s)),
         })
     }
 }
 
+impl OutputType {
+    fn to_file_name(&self, output_path: Option<&Path>) -> Option<PathBuf> {
+        output_path.map(|path| {
+            if path.is_dir() {
+                match self {
+                    OutputType::Ade => path.join("activedata"),
+                    OutputType::Lcov => path.join("lcov"),
+                    OutputType::Coveralls => path.join("coveralls"),
+                    OutputType::CoverallsPlus => path.join("coveralls+"),
+                    OutputType::Files => path.join("files"),
+                    OutputType::Covdir => path.join("covdir"),
+                    OutputType::Html => path.join("html"),
+                    OutputType::Cobertura => path.join("cobertura.xml"),
+                    OutputType::Markdown => path.join("markdown.md"),
+                }
+            } else {
+                path.to_path_buf()
+            }
+        })
+    }
+}
+
+#[derive(clap::ValueEnum, Clone)]
 enum Filter {
     Covered,
     Uncovered,
@@ -65,24 +91,72 @@ impl FromStr for Filter {
     }
 }
 
-#[derive(StructOpt)]
-#[structopt(
+#[derive(Copy, Clone, Debug, PartialEq, Eq)]
+struct LevelFilterArg(LevelFilter);
+
+impl ValueEnum for LevelFilterArg {
+    fn value_variants<'a>() -> &'a [Self] {
+        &[
+            Self(LevelFilter::Off),
+            Self(LevelFilter::Error),
+            Self(LevelFilter::Warn),
+            Self(LevelFilter::Info),
+            Self(LevelFilter::Debug),
+            Self(LevelFilter::Trace),
+        ]
+    }
+
+    fn to_possible_value(&self) -> Option<PossibleValue> {
+        match self.0 {
+            LevelFilter::Off => Some(PossibleValue::new("OFF")),
+            LevelFilter::Error => Some(PossibleValue::new("ERROR")),
+            LevelFilter::Warn => Some(PossibleValue::new("WARN")),
+            LevelFilter::Info => Some(PossibleValue::new("INFO")),
+            LevelFilter::Debug => Some(PossibleValue::new("DEBUG")),
+            LevelFilter::Trace => Some(PossibleValue::new("TRACE")),
+        }
+    }
+}
+
+#[derive(Parser)]
+#[command(
     author,
-    about = "Parse, collect and aggregate code coverage data for multiple source files"
+    version,
+    max_term_width = 100,
+    about = "Parse, collect and aggregate code coverage data for multiple source files",
+    help_template = "\
+{before-help}{name}
+{author-with-newline}{about-with-newline}
+{usage-heading} {usage}
+
+{all-args}{after-help}
+",
+    // This group requires that at least one of --token and --service-job-id
+    // be present. --service-job-id requires --service-name, so this
+    // effectively means we accept the following combinations:
+    // - --token
+    // - --token --service-job-id --service-name
+    // - --service-job-id --service-name
+    group = ArgGroup::new("coveralls-auth")
+        .args(&["token", "service_job_id"])
+        .multiple(true),
 )]
 struct Opt {
     /// Sets the input paths to use.
-    #[structopt(required = true)]
+    #[arg(required = true)]
     paths: Vec<String>,
     /// Sets the path to the compiled binary to be used.
-    #[structopt(short, long, value_name = "PATH")]
+    #[arg(short, long, value_name = "PATH")]
     binary_path: Option<PathBuf>,
+    /// Sets the path to the LLVM bin directory.
+    #[arg(long, value_name = "PATH")]
+    llvm_path: Option<PathBuf>,
     /// Sets a custom output type.
-    #[structopt(
-        short = "t",
+    #[arg(
+        short = 't',
         long,
         long_help = "\
-            Sets a custom output type:\n\
+            Comma separated list of custom output types:\n\
             - *html* for a HTML coverage report;\n\
             - *coveralls* for the Coveralls specific format;\n\
             - *lcov* for the lcov INFO format;\n\
@@ -90,146 +164,133 @@ struct Opt {
             - *coveralls+* for the Coveralls specific format with function information;\n\
             - *ade* for the ActiveData-ETL specific format;\n\
             - *files* to only return a list of files.\n\
+            - *markdown* for human easy read.\n\
+            - *cobertura* for output in cobertura format.\n\
         ",
         value_name = "OUTPUT TYPE",
-        default_value = "lcov",
-        requires_ifs = &[
+        requires_ifs = [
             ("coveralls", "coveralls-auth"),
             ("coveralls+", "coveralls-auth"),
         ],
-        possible_values = &[
-            "ade",
-            "lcov",
-            "coveralls",
-            "coveralls+",
-            "files",
-            "covdir",
-            "html",
-            "cobertura",
-        ],
+
+        value_delimiter = ',',
+        alias = "output-type",
+        default_value = "lcov",
     )]
-    output_type: OutputType,
-    /// Specifies the output path.
-    #[structopt(short, long, value_name = "PATH", alias = "output-file")]
+    output_types: Vec<OutputType>,
+    /// Specifies the output path. This is a file for a single output type and must be a folder
+    /// for multiple output types.
+    #[arg(short, long, value_name = "PATH", alias = "output-file")]
     output_path: Option<PathBuf>,
     /// Specifies the output config file.
-    #[structopt(long, value_name = "PATH", alias = "output-config-file")]
+    #[arg(long, value_name = "PATH", alias = "output-config-file")]
     output_config_file: Option<PathBuf>,
     /// Specifies the root directory of the source files.
-    #[structopt(short, long, value_name = "DIRECTORY", parse(from_os_str))]
+    #[arg(short, long, value_name = "DIRECTORY")]
     source_dir: Option<PathBuf>,
     /// Specifies a prefix to remove from the paths (e.g. if grcov is run on a different machine
     /// than the one that generated the code coverage information).
-    #[structopt(short, long, value_name = "PATH")]
+    #[arg(short, long, value_name = "PATH")]
     prefix_dir: Option<PathBuf>,
     /// Ignore source files that can't be found on the disk.
-    #[structopt(long)]
+    #[arg(long)]
     ignore_not_existing: bool,
     /// Ignore files/directories specified as globs.
-    #[structopt(long = "ignore", value_name = "PATH", number_of_values = 1)]
+    #[arg(long = "ignore", value_name = "PATH", num_args = 1)]
     ignore_dir: Vec<String>,
     /// Keep only files/directories specified as globs.
-    #[structopt(long = "keep-only", value_name = "PATH", number_of_values = 1)]
+    #[arg(long = "keep-only", value_name = "PATH", num_args = 1)]
     keep_dir: Vec<String>,
-    #[structopt(long, value_name = "PATH")]
+    #[arg(long, value_name = "PATH")]
     path_mapping: Option<PathBuf>,
     /// Enables parsing branch coverage information.
-    #[structopt(long)]
+    #[arg(long)]
     branch: bool,
     /// Filters out covered/uncovered files. Use 'covered' to only return covered files, 'uncovered'
     /// to only return uncovered files.
-    #[structopt(long, possible_values = &["covered", "uncovered"])]
+    #[arg(long, value_enum)]
     filter: Option<Filter>,
     /// Speeds-up parsing, when the code coverage information is exclusively coming from a llvm
     /// build.
-    #[structopt(long)]
+    #[arg(long)]
     llvm: bool,
     /// Sets the repository token from Coveralls, required for the 'coveralls' and 'coveralls+'
     /// formats.
-    #[structopt(long, value_name = "TOKEN")]
+    #[arg(long, value_name = "TOKEN")]
     token: Option<String>,
     /// Sets the hash of the commit used to generate the code coverage data.
-    #[structopt(long, value_name = "COMMIT HASH")]
+    #[arg(long, value_name = "COMMIT HASH")]
     commit_sha: Option<String>,
     /// Sets the service name.
-    #[structopt(long, value_name = "SERVICE NAME")]
+    #[arg(long, value_name = "SERVICE NAME")]
     service_name: Option<String>,
     /// Sets the service number.
-    #[structopt(long, value_name = "SERVICE NUMBER")]
+    #[arg(long, value_name = "SERVICE NUMBER")]
     service_number: Option<String>,
     /// Sets the service job id.
-    #[structopt(
+    #[arg(
         long,
         value_name = "SERVICE JOB ID",
         visible_alias = "service-job-number",
-        requires = "service-name"
+        requires = "service_name"
     )]
     service_job_id: Option<String>,
     /// Sets the service pull request number.
-    #[structopt(long, value_name = "SERVICE PULL REQUEST")]
+    #[arg(long, value_name = "SERVICE PULL REQUEST")]
     service_pull_request: Option<String>,
+    /// Sets the service flag name for coveralls parallel/carryover mode
+    #[arg(long, value_name = "SERVICE FLAG NAME")]
+    service_flag_name: Option<String>,
     /// Sets the build type to be parallel for 'coveralls' and 'coveralls+' formats.
-    #[structopt(long)]
+    #[arg(long)]
     parallel: bool,
-    #[structopt(long, value_name = "NUMBER")]
+    #[arg(long, value_name = "NUMBER")]
     threads: Option<usize>,
-    #[structopt(long = "guess-directory-when-missing")]
+    /// Sets coverage decimal point precision on output reports.
+    #[arg(long, value_name = "NUMBER", default_value = "2")]
+    precision: usize,
+    #[arg(long = "guess-directory-when-missing")]
     guess_directory: bool,
     /// Set the branch for coveralls report. Defaults to 'master'.
-    #[structopt(long, value_name = "VCS BRANCH", default_value = "master")]
+    #[arg(long, value_name = "VCS BRANCH", default_value = "master")]
     vcs_branch: String,
     /// Set the file where to log (or stderr or stdout). Defaults to 'stderr'.
-    #[structopt(long, value_name = "LOG", default_value = "stderr")]
+    #[arg(long, value_name = "LOG", default_value = "stderr")]
     log: PathBuf,
     /// Set the log level.
-    #[structopt(
-        long,
-        value_name = "LEVEL",
-        default_value = "ERROR",
-        possible_values = &["OFF", "ERROR","WARN", "INFO", "DEBUG", "TRACE"],
-    )]
-    log_level: LevelFilter,
+    #[arg(long, value_name = "LEVEL", default_value = "ERROR", value_enum)]
+    log_level: LevelFilterArg,
     /// Lines in covered files containing this marker will be excluded.
-    #[structopt(long, value_name = "regex")]
+    #[arg(long, value_name = "regex")]
     excl_line: Option<Regex>,
     /// Marks the beginning of an excluded section. The current line is part of this section.
-    #[structopt(long, value_name = "regex")]
+    #[arg(long, value_name = "regex")]
     excl_start: Option<Regex>,
     /// Marks the end of an excluded section. The current line is part of this section.
-    #[structopt(long, value_name = "regex")]
+    #[arg(long, value_name = "regex")]
     excl_stop: Option<Regex>,
     /// Lines in covered files containing this marker will be excluded from branch coverage.
-    #[structopt(long, value_name = "regex")]
+    #[arg(long, value_name = "regex")]
     excl_br_line: Option<Regex>,
     /// Marks the beginning of a section excluded from branch coverage. The current line is part of
     /// this section.
-    #[structopt(long, value_name = "regex")]
+    #[arg(long, value_name = "regex")]
     excl_br_start: Option<Regex>,
     /// Marks the end of a section excluded from branch coverage. The current line is part of this
     /// section.
-    #[structopt(long, value_name = "regex")]
+    #[arg(long, value_name = "regex")]
     excl_br_stop: Option<Regex>,
     /// No symbol demangling.
-    #[structopt(long)]
+    #[arg(long)]
     no_demangle: bool,
 }
 
 fn main() {
-    let opt = Opt::from_clap(
-        &Opt::clap()
-            // This group requires that at least one of --token and --service-job-id
-            // be present. --service-job-id requires --service-name, so this
-            // effectively means we accept the following combinations:
-            // - --token
-            // - --token --service-job-id --service-name
-            // - --service-job-id --service-name
-            .group(
-                ArgGroup::with_name("coveralls-auth")
-                    .args(&["token", "service-job-id"])
-                    .multiple(true),
-            )
-            .get_matches(),
-    );
+    let opt = Opt::parse();
+
+    if let Some(path) = opt.llvm_path {
+        LLVM_PATH.set(path).unwrap();
+    }
 
     let filter_option = opt.filter.map(|filter| match filter {
         Filter::Covered => true,
@@ -240,23 +301,23 @@ fn main() {
 
     if opt.log == stdout {
         let _ = TermLogger::init(
-            opt.log_level,
+            opt.log_level.0,
             Config::default(),
             TerminalMode::Stdout,
             ColorChoice::Auto,
         );
     } else if opt.log == stderr {
         let _ = TermLogger::init(
-            opt.log_level,
+            opt.log_level.0,
             Config::default(),
             TerminalMode::Stderr,
             ColorChoice::Auto,
         );
     } else if let Ok(file) = File::create(&opt.log) {
-        let _ = WriteLogger::init(opt.log_level, Config::default(), file);
+        let _ = WriteLogger::init(opt.log_level.0, Config::default(), file);
     } else {
         let _ = TermLogger::init(
-            opt.log_level,
+            opt.log_level.0,
             Config::default(),
             TerminalMode::Stderr,
             ColorChoice::Auto,
@@ -300,9 +361,7 @@ fn main() {
     let source_root = opt
         .source_dir
         .filter(|source_dir| source_dir != Path::new(""))
-        .map(|source_dir| {
-            canonicalize_path(&source_dir).expect("Source directory does not exist.")
-        });
+        .map(|source_dir| canonicalize_path(source_dir).expect("Source directory does not exist."));
 
     let prefix_dir = opt.prefix_dir.or_else(|| source_root.clone());
 
@@ -411,51 +470,94 @@ fn main() {
         file_filter,
     );
 
-    match opt.output_type {
-        OutputType::Ade => output_activedata_etl(iterator, opt.output_path.as_deref(), demangle),
-        OutputType::Lcov => output_lcov(iterator, opt.output_path.as_deref(), demangle),
-        OutputType::Coveralls => output_coveralls(
-            iterator,
-            opt.token.as_deref(),
-            opt.service_name.as_deref(),
-            &opt.service_number.unwrap_or_default(),
-            opt.service_job_id.as_deref(),
-            &opt.service_pull_request.unwrap_or_default(),
-            &opt.commit_sha.unwrap_or_default(),
-            false,
-            opt.output_path.as_deref(),
-            &opt.vcs_branch,
-            opt.parallel,
-            demangle,
-        ),
-        OutputType::CoverallsPlus => output_coveralls(
-            iterator,
-            opt.token.as_deref(),
-            opt.service_name.as_deref(),
-            &opt.service_number.unwrap_or_default(),
-            opt.service_job_id.as_deref(),
-            &opt.service_pull_request.unwrap_or_default(),
-            &opt.commit_sha.unwrap_or_default(),
-            true,
-            opt.output_path.as_deref(),
-            &opt.vcs_branch,
-            opt.parallel,
-            demangle,
-        ),
-        OutputType::Files => output_files(iterator, opt.output_path.as_deref()),
-        OutputType::Covdir => output_covdir(iterator, opt.output_path.as_deref()),
-        OutputType::Html => output_html(
-            iterator,
-            opt.output_path.as_deref(),
-            num_threads,
-            opt.branch,
-            opt.output_config_file.as_deref(),
-        ),
-        OutputType::Cobertura => output_cobertura(
-            source_root.as_deref(),
-            iterator,
-            opt.output_path.as_deref(),
-            demangle,
-        ),
+    let service_number = opt.service_number.unwrap_or_default();
+    let service_pull_request = opt.service_pull_request.unwrap_or_default();
+    let commit_sha = opt.commit_sha.unwrap_or_default();
+
+    let output_types = opt.output_types;
+
+    let output_path = match output_types.len() {
+        0 => unreachable!("Output types has a default value"),
+        1 => opt.output_path.as_deref(),
+        _ => match opt.output_path.as_deref() {
+            Some(output_path) => {
+                if output_path.is_dir() {
+                    Some(output_path)
+                } else {
+                    panic!("output_path must be a directory when using multiple outputs");
+                }
+            }
+            _ => None,
+        },
     };
+
+    for output_type in &output_types {
+        let output_path = output_type.to_file_name(output_path);
+
+        match output_type {
+            OutputType::Ade => output_activedata_etl(&iterator, output_path.as_deref(), demangle),
+            OutputType::Lcov => output_lcov(&iterator, output_path.as_deref(), demangle),
+            OutputType::Coveralls => output_coveralls(
+                &iterator,
+                opt.token.as_deref(),
+                opt.service_name.as_deref(),
+                &service_number,
+                opt.service_job_id.as_deref(),
+                &service_pull_request,
+                opt.service_flag_name.as_deref(),
+                &commit_sha,
+                false,
+                output_path.as_deref(),
+                &opt.vcs_branch,
+                opt.parallel,
+                demangle,
+            ),
+            OutputType::CoverallsPlus => output_coveralls(
+                &iterator,
+                opt.token.as_deref(),
+                opt.service_name.as_deref(),
+                &service_number,
+                opt.service_job_id.as_deref(),
+                &service_pull_request,
+                opt.service_flag_name.as_deref(),
+                &commit_sha,
+                true,
+                output_path.as_deref(),
+                &opt.vcs_branch,
+                opt.parallel,
+                demangle,
+            ),
+            OutputType::Files => output_files(&iterator, output_path.as_deref()),
+            OutputType::Covdir => output_covdir(&iterator, output_path.as_deref(), opt.precision),
+            OutputType::Html => output_html(
+                &iterator,
+                output_path.as_deref(),
+                num_threads,
+                opt.branch,
+                opt.output_config_file.as_deref(),
+                opt.precision,
+            ),
+            OutputType::Cobertura => output_cobertura(
+                source_root.as_deref(),
+                &iterator,
+                output_path.as_deref(),
+                demangle,
+            ),
+            OutputType::Markdown => {
+                output_markdown(&iterator, output_path.as_deref(), opt.precision)
+            }
+        };
+    }
+}
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+
+    use clap::CommandFactory;
+
+    #[test]
+    fn clap_debug_assert() {
+        Opt::command().debug_assert();
+    }
 }
