@@ -105,8 +105,8 @@ fn guess_abs_path(prefix_dir: &Path, path: &Path) -> PathBuf {
 // Remove prefix from the source file's path.
 fn remove_prefix(prefix_dir: Option<&Path>, path: PathBuf) -> PathBuf {
     if let Some(prefix_dir) = prefix_dir {
-        if path.starts_with(&prefix_dir) {
-            return path.strip_prefix(&prefix_dir).unwrap().to_path_buf();
+        if path.starts_with(prefix_dir) {
+            return path.strip_prefix(prefix_dir).unwrap().to_path_buf();
         }
     }
 
@@ -115,8 +115,8 @@ fn remove_prefix(prefix_dir: Option<&Path>, path: PathBuf) -> PathBuf {
 
 fn fixup_rel_path(source_dir: Option<&Path>, abs_path: &Path, rel_path: PathBuf) -> PathBuf {
     if let Some(ref source_dir) = source_dir {
-        if abs_path.starts_with(&source_dir) {
-            return abs_path.strip_prefix(&source_dir).unwrap().to_path_buf();
+        if abs_path.starts_with(source_dir) {
+            return abs_path.strip_prefix(source_dir).unwrap().to_path_buf();
         } else if !rel_path.is_relative() {
             return abs_path.to_owned();
         }
@@ -235,7 +235,7 @@ pub fn rewrite_paths(
     to_keep_dirs: &[impl AsRef<str>],
     filter_option: Option<bool>,
     file_filter: crate::FileFilter,
-) -> CovResultIter {
+) -> Vec<ResultTuple> {
     let to_ignore_globset = to_globset(to_ignore_dirs);
     let to_keep_globset = to_globset(to_keep_dirs);
 
@@ -246,7 +246,7 @@ pub fn rewrite_paths(
     // Traverse source dir and store all paths, reversed.
     let mut file_to_paths: FxHashMap<String, Vec<PathBuf>> = FxHashMap::default();
     if let Some(ref source_dir) = source_dir {
-        for entry in WalkDir::new(&source_dir)
+        for entry in WalkDir::new(source_dir)
             .into_iter()
             .filter_entry(|e| !is_hidden(e) && !is_symbolic_link(e))
         {
@@ -258,7 +258,7 @@ pub fn rewrite_paths(
                 continue;
             }
 
-            let path = full_path.strip_prefix(&source_dir).unwrap().to_path_buf();
+            let path = full_path.strip_prefix(source_dir).unwrap().to_path_buf();
             if to_ignore_globset.is_match(&path) {
                 continue;
             }
@@ -341,11 +341,7 @@ pub fn rewrite_paths(
             Some((abs_path, rel_path, result))
         });
 
-    Box::new(
-        results
-            .collect::<Vec<(PathBuf, PathBuf, CovResult)>>()
-            .into_iter(),
-    )
+    results.collect()
 }
 
 #[cfg(test)]
@@ -933,6 +929,7 @@ mod tests {
             None,
             Default::default(),
         )
+        .iter()
         .any(|_| false);
     }
 
@@ -1052,7 +1049,7 @@ mod tests {
         let mut result_map: CovResultMap = FxHashMap::default();
         result_map.insert("java/main.java".to_string(), empty_result!());
         result_map.insert("main.rs".to_string(), empty_result!());
-        let results = rewrite_paths(
+        let mut results = rewrite_paths(
             result_map,
             None,
             Some(&canonicalize_path(".").unwrap()),
@@ -1063,7 +1060,6 @@ mod tests {
             None,
             Default::default(),
         );
-        let mut results: Vec<(PathBuf, PathBuf, CovResult)> = results.collect();
         assert!(results.len() == 1);
 
         let (abs_path, rel_path, result) = results.remove(0);
@@ -1079,7 +1075,7 @@ mod tests {
         let mut result_map: CovResultMap = FxHashMap::default();
         result_map.insert("java\\main.java".to_string(), empty_result!());
         result_map.insert("main.rs".to_string(), empty_result!());
-        let results = rewrite_paths(
+        let mut results = rewrite_paths(
             result_map,
             None,
             Some(&canonicalize_path(".").unwrap()),
@@ -1090,7 +1086,6 @@ mod tests {
             None,
             Default::default(),
         );
-        let mut results: Vec<(PathBuf, PathBuf, CovResult)> = results.collect();
         assert!(results.len() == 1);
 
         let (abs_path, rel_path, result) = results.remove(0);
